
# Type: has qualitative value


connects an attribute to a value

URI: [biolink:has_qualitative_value](https://w3id.org/biolink/vocab/has_qualitative_value)


## Domain and Range

[Attribute](Attribute.md) ->  <sub>OPT</sub> [NamedThing](NamedThing.md)

## Parents


## Children


## Used by

 * [Attribute](Attribute.md)
 * [BiologicalSex](BiologicalSex.md)
 * [ClinicalModifier](ClinicalModifier.md)
 * [FrequencyValue](FrequencyValue.md)
 * [GenotypicSex](GenotypicSex.md)
 * [Onset](Onset.md)
 * [PhenotypicSex](PhenotypicSex.md)
 * [SeverityValue](SeverityValue.md)
 * [Zygosity](Zygosity.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | samples |

